@@ -15,6 +15,7 @@
  */
 package org.drools.workbench.screens.guided.dtable.client.widget.table;
 
+import java.util.ArrayList;
 import java.util.List;
 
 import javax.enterprise.event.Event;
@@ -34,13 +35,17 @@ import com.google.gwt.core.client.GWT;
 import org.drools.workbench.models.guided.dtable.shared.model.BaseColumn;
 import org.drools.workbench.models.guided.dtable.shared.model.GuidedDecisionTable52;
 import org.drools.workbench.screens.guided.dtable.client.resources.i18n.GuidedDecisionTableConstants;
+import org.drools.workbench.screens.guided.dtable.client.widget.table.themes.GuidedDecisionTableRenderer;
 import org.drools.workbench.screens.guided.dtable.client.widget.table.themes.GuidedDecisionTableTheme;
 import org.uberfire.ext.widgets.common.client.common.BusyPopup;
 import org.uberfire.ext.wires.core.grids.client.model.GridData;
 import org.uberfire.ext.wires.core.grids.client.util.CoordinateUtilities;
+import org.uberfire.ext.wires.core.grids.client.widget.grid.NodeMouseEventHandler;
 import org.uberfire.ext.wires.core.grids.client.widget.grid.impl.BaseGridWidget;
 import org.uberfire.ext.wires.core.grids.client.widget.grid.renderers.grids.GridRenderer;
 import org.uberfire.ext.wires.core.grids.client.widget.grid.renderers.grids.impl.BaseGridRendererHelper;
+import org.uberfire.ext.wires.core.grids.client.widget.layer.GridSelectionManager;
+import org.uberfire.ext.wires.core.grids.client.widget.layer.pinning.GridPinnedModeManager;
 import org.uberfire.workbench.events.NotificationEvent;
 
 public class GuidedDecisionTableViewImpl extends BaseGridWidget implements GuidedDecisionTableView {
@@ -83,9 +88,17 @@ public class GuidedDecisionTableViewImpl extends BaseGridWidget implements Guide
         addNodeMouseDoubleClickHandler(handler);
     }
 
+    @Override
+    protected List<NodeMouseEventHandler> getNodeMouseDoubleClickEventHandlers(final GridSelectionManager selectionManager,
+                                                                               final GridPinnedModeManager pinnedModeManager) {
+        final List<NodeMouseEventHandler> handlers = new ArrayList<>();
+        handlers.add(new GuidedDecisionTableSortGridWidgetMouseEventHandler(column -> presenter.onSort(column)));
+        return handlers;
+    }
+
     private Group makeHeaderCaption() {
         final Group g = GWT.create(Group.class);
-        final double captionWidth = getHeaderCaptionWidth();
+        final double captionWidth = ((GuidedDecisionTableRenderer) renderer).getHeaderCaptionWidth();
         final GuidedDecisionTableTheme theme = (GuidedDecisionTableTheme) renderer.getTheme();
         final Rectangle r = theme.getBaseRectangle(GuidedDecisionTableTheme.ModelColumnType.CAPTION);
         r.setWidth(captionWidth);
@@ -129,11 +142,6 @@ public class GuidedDecisionTableViewImpl extends BaseGridWidget implements Guide
         return new BoundingBoxPathClipper(bb);
     }
 
-    private double getHeaderCaptionWidth() {
-        return Math.max(HEADER_CAPTION_WIDTH,
-                        model.getRowNumberCol().getWidth() + model.getDescriptionCol().getWidth());
-    }
-
     @Override
     public boolean onDragHandle(final INodeXYEvent event) {
         return isNodeMouseEventOverCaption(event);
@@ -147,7 +155,7 @@ public class GuidedDecisionTableViewImpl extends BaseGridWidget implements Guide
         final double cx = ap.getX();
         final double cy = ap.getY();
 
-        if (cx > headerCaption.getX() && cx < headerCaption.getX() + getHeaderCaptionWidth()) {
+        if (cx > headerCaption.getX() && cx < headerCaption.getX() + ((GuidedDecisionTableRenderer) renderer).getHeaderCaptionWidth()) {
             if (cy > headerCaption.getY() && cy < headerCaption.getY() + HEADER_CAPTION_HEIGHT) {
                 return true;
             }
