@@ -31,8 +31,9 @@ import javax.enterprise.event.Event;
 import com.google.gwt.event.shared.EventBus;
 import com.google.gwt.event.shared.HandlerRegistration;
 import org.drools.scenariosimulation.api.model.FactMappingValueType;
-import org.drools.workbench.screens.scenariosimulation.client.commands.actualcommands.AbstractScenarioGridCommand;
+import org.drools.scenariosimulation.api.utils.ScenarioSimulationSharedUtils;
 import org.drools.workbench.screens.scenariosimulation.client.commands.actualcommands.AbstractScenarioSimulationCommand;
+import org.drools.workbench.screens.scenariosimulation.client.commands.actualcommands.AbstractScenarioSimulationUndoableCommand;
 import org.drools.workbench.screens.scenariosimulation.client.commands.actualcommands.AppendColumnCommand;
 import org.drools.workbench.screens.scenariosimulation.client.commands.actualcommands.AppendRowCommand;
 import org.drools.workbench.screens.scenariosimulation.client.commands.actualcommands.DeleteColumnCommand;
@@ -52,6 +53,7 @@ import org.drools.workbench.screens.scenariosimulation.client.commands.actualcom
 import org.drools.workbench.screens.scenariosimulation.client.commands.actualcommands.SetHeaderCellValueCommand;
 import org.drools.workbench.screens.scenariosimulation.client.commands.actualcommands.SetInstanceHeaderCommand;
 import org.drools.workbench.screens.scenariosimulation.client.commands.actualcommands.SetPropertyHeaderCommand;
+import org.drools.workbench.screens.scenariosimulation.client.commands.actualcommands.UpdateSettingsDataCommand;
 import org.drools.workbench.screens.scenariosimulation.client.editor.ScenarioSimulationEditorPresenter;
 import org.drools.workbench.screens.scenariosimulation.client.enums.GridWidget;
 import org.drools.workbench.screens.scenariosimulation.client.events.AppendColumnEvent;
@@ -78,6 +80,7 @@ import org.drools.workbench.screens.scenariosimulation.client.events.SetInstance
 import org.drools.workbench.screens.scenariosimulation.client.events.SetPropertyHeaderEvent;
 import org.drools.workbench.screens.scenariosimulation.client.events.UndoEvent;
 import org.drools.workbench.screens.scenariosimulation.client.events.UnsupportedDMNEvent;
+import org.drools.workbench.screens.scenariosimulation.client.events.UpdateSettingsDataEvent;
 import org.drools.workbench.screens.scenariosimulation.client.events.ValidateSimulationEvent;
 import org.drools.workbench.screens.scenariosimulation.client.handlers.AppendColumnEventHandler;
 import org.drools.workbench.screens.scenariosimulation.client.handlers.AppendRowEventHandler;
@@ -103,6 +106,7 @@ import org.drools.workbench.screens.scenariosimulation.client.handlers.SetInstan
 import org.drools.workbench.screens.scenariosimulation.client.handlers.SetPropertyHeaderEventHandler;
 import org.drools.workbench.screens.scenariosimulation.client.handlers.UndoEventHandler;
 import org.drools.workbench.screens.scenariosimulation.client.handlers.UnsupportedDMNEventHandler;
+import org.drools.workbench.screens.scenariosimulation.client.handlers.UpdateSettingsDataEventHandler;
 import org.drools.workbench.screens.scenariosimulation.client.handlers.ValidateSimulationEventHandler;
 import org.drools.workbench.screens.scenariosimulation.client.models.AbstractScesimGridModel;
 import org.drools.workbench.screens.scenariosimulation.client.popup.ConfirmPopupPresenter;
@@ -148,6 +152,7 @@ public class ScenarioSimulationEventHandler implements AppendColumnEventHandler,
                                                        SetPropertyHeaderEventHandler,
                                                        UndoEventHandler,
                                                        UnsupportedDMNEventHandler,
+                                                       UpdateSettingsDataEventHandler,
                                                        ValidateSimulationEventHandler {
 
     protected DeletePopupPresenter deletePopupPresenter;
@@ -341,7 +346,7 @@ public class ScenarioSimulationEventHandler implements AppendColumnEventHandler,
 
     @Override
     public void onEvent(ScenarioNotificationEvent event) {
-        notificationEvent.fire(new NotificationEvent(event.getMessage(), event.getNotificationType()));
+        notificationEvent.fire(new NotificationEvent(event.getMessage(), event.getNotificationType()).setAutoHide(event.isAutoHide()));
     }
 
     @Override
@@ -398,46 +403,73 @@ public class ScenarioSimulationEventHandler implements AppendColumnEventHandler,
             return;
         }
         context.getStatus().setFullPackage(event.getFullPackage());
+        context.getStatus().setClassName(event.getFactType());
         context.getStatus().setPropertyNameElements(event.getPropertyNameElements());
         context.getStatus().setValueClassName(event.getValueClassName());
-        if (context.getAbstractScesimGridModelByGridWidget(event.getGridWidget()).isSelectedColumnEmpty()) {
-            commonExecution(new SetPropertyHeaderCommand(event.getGridWidget(), event.getFactMappingValueType()), true);
-        } else if (context.getAbstractScesimGridModelByGridWidget(event.getGridWidget()).isSameSelectedColumnProperty(event.getPropertyNameElements())) {
+        context.getStatus().setImportPrefix(event.getImportPrefix());
+        if (isSameFactProperty(event.getGridWidget(), event.getPropertyNameElements(), event.getFactMappingValueType()) &&
+                isSameSelectedColumnType(event.getGridWidget(), event.getValueClassName())) {
             return;
-        } else if (context.getAbstractScesimGridModelByGridWidget(event.getGridWidget()).isSameSelectedColumnType(event.getValueClassName())) {
-            org.uberfire.mvp.Command okDeleteCommand = () -> {
-                context.getStatus().setKeepData(false);
+        } else {
+            if (isSelectedColumnEmpty(event.getGridWidget())) {
                 commonExecution(new SetPropertyHeaderCommand(event.getGridWidget(), event.getFactMappingValueType()), true);
-            };
-            org.uberfire.mvp.Command okPreserveCommand = () -> {
-                context.getStatus().setKeepData(true);
-                commonExecution(new SetPropertyHeaderCommand(event.getGridWidget(), event.getFactMappingValueType()), true);
-            };
-            preserveDeletePopupPresenter.show(ScenarioSimulationEditorConstants.INSTANCE.preserveDeleteScenarioMainTitle(),
-                                              ScenarioSimulationEditorConstants.INSTANCE.preserveDeleteScenarioMainQuestion(),
-                                              ScenarioSimulationEditorConstants.INSTANCE.preserveDeleteScenarioText1(),
-                                              ScenarioSimulationEditorConstants.INSTANCE.preserveDeleteScenarioTextQuestion(),
-                                              ScenarioSimulationEditorConstants.INSTANCE.preserveDeleteScenarioTextOption1(),
-                                              ScenarioSimulationEditorConstants.INSTANCE.preserveDeleteScenarioTextOption2(),
-                                              ScenarioSimulationEditorConstants.INSTANCE.preserveValues(),
-                                              ScenarioSimulationEditorConstants.INSTANCE.deleteValues(),
-                                              okPreserveCommand,
-                                              okDeleteCommand);
-        } else if (!context.getAbstractScesimGridModelByGridWidget(event.getGridWidget()).isSameSelectedColumnType(event.getValueClassName())) {
-            org.uberfire.mvp.Command okPreserveCommand = () -> {
-                context.getStatus().setKeepData(false);
-                commonExecution(new SetPropertyHeaderCommand(event.getGridWidget(), event.getFactMappingValueType()), true);
-            };
-            deletePopupPresenter.show(ScenarioSimulationEditorConstants.INSTANCE.deleteScenarioMainTitle(),
-                                      ScenarioSimulationEditorConstants.INSTANCE.deleteScenarioMainQuestion(),
-                                      ScenarioSimulationEditorConstants.INSTANCE.deleteScenarioText1(),
-                                      ScenarioSimulationEditorConstants.INSTANCE.deleteScenarioTextQuestion(),
-                                      ScenarioSimulationEditorConstants.INSTANCE.deleteScenarioTextDanger(),
-                                      ScenarioSimulationEditorConstants.INSTANCE.deleteValues(),
-                                      okPreserveCommand);
+            } else {
+                if (isSameSelectedColumnType(event.getGridWidget(), event.getValueClassName()) && !ScenarioSimulationSharedUtils.isCollectionOrMap(event.getValueClassName())) {
+                    showPreserveDeletePopup(event);
+                } else {
+                    showDeletePopup(event);
+                }
+            }
         }
     }
 
+    private boolean isSelectedColumnEmpty(GridWidget gridWidget) {
+        return context.getAbstractScesimGridModelByGridWidget(gridWidget).isSelectedColumnEmpty();
+    }
+
+    private boolean isSameFactProperty(GridWidget gridWidget, List<String> propertyNameElements, FactMappingValueType factMappingValueType) {
+        return context.getAbstractScesimGridModelByGridWidget(gridWidget).isSameSelectedColumnProperty(propertyNameElements, factMappingValueType);
+    }
+
+    private boolean isSameSelectedColumnType(GridWidget gridWidget, String valueTypeName) {
+        return context.getAbstractScesimGridModelByGridWidget(gridWidget).isSameSelectedColumnType(valueTypeName);
+    }
+
+    private void showDeletePopup(SetPropertyHeaderEvent event) {
+        org.uberfire.mvp.Command okPreserveCommand = () -> {
+            context.getStatus().setKeepData(false);
+            commonExecution(new SetPropertyHeaderCommand(event.getGridWidget(), event.getFactMappingValueType()), true);
+        };
+        deletePopupPresenter.show(ScenarioSimulationEditorConstants.INSTANCE.deleteScenarioMainTitle(),
+                                  ScenarioSimulationEditorConstants.INSTANCE.deleteScenarioMainQuestion(),
+                                  ScenarioSimulationEditorConstants.INSTANCE.deleteScenarioText1(),
+                                  ScenarioSimulationEditorConstants.INSTANCE.deleteScenarioTextQuestion(),
+                                  null,
+                                  ScenarioSimulationEditorConstants.INSTANCE.deleteValues(),
+                                  okPreserveCommand);
+    }
+
+    private void showPreserveDeletePopup(SetPropertyHeaderEvent event) {
+        org.uberfire.mvp.Command okDeleteCommand = () -> {
+            context.getStatus().setKeepData(false);
+            commonExecution(new SetPropertyHeaderCommand(event.getGridWidget(), event.getFactMappingValueType()), true);
+        };
+        org.uberfire.mvp.Command okPreserveCommand = () -> {
+            context.getStatus().setKeepData(true);
+            commonExecution(new SetPropertyHeaderCommand(event.getGridWidget(), event.getFactMappingValueType()), true);
+        };
+        preserveDeletePopupPresenter.show(ScenarioSimulationEditorConstants.INSTANCE.preserveDeleteScenarioMainTitle(),
+                                          ScenarioSimulationEditorConstants.INSTANCE.preserveDeleteScenarioMainQuestion(),
+                                          ScenarioSimulationEditorConstants.INSTANCE.preserveDeleteScenarioText1(),
+                                          ScenarioSimulationEditorConstants.INSTANCE.preserveDeleteScenarioTextQuestion(),
+                                          ScenarioSimulationEditorConstants.INSTANCE.preserveDeleteScenarioTextOption1(),
+                                          ScenarioSimulationEditorConstants.INSTANCE.preserveDeleteScenarioTextOption2(),
+                                          ScenarioSimulationEditorConstants.INSTANCE.preserveValues(),
+                                          ScenarioSimulationEditorConstants.INSTANCE.deleteValues(),
+                                          okPreserveCommand,
+                                          okDeleteCommand);
+    }
+
     @Override
     public void onEvent(UndoEvent event) {
         final CommandResult<ScenarioSimulationViolation> status = scenarioCommandRegistryManager.undo(context);
@@ -451,6 +483,16 @@ public class ScenarioSimulationEventHandler implements AppendColumnEventHandler,
         confirmPopupPresenter.show("Unsupported DMN asset", event.getMessage());
     }
 
+    @Override
+    public void onEvent(UpdateSettingsDataEvent updateSettingsDataEvent) {
+        if (updateSettingsDataEvent.getSettingsValueChanged().test(context.getScenarioSimulationModel().getSettings())) {
+            commonExecution(new UpdateSettingsDataCommand(updateSettingsDataEvent.getSettingsChangeToApply(),
+                                                          updateSettingsDataEvent.isDmnPathChanged()),
+                            false);
+            scenarioSimulationEditorPresenter.unpublishTestResultsAlerts();
+        }
+    }
+
     @Override
     public void onEvent(ValidateSimulationEvent event) {
         scenarioSimulationEditorPresenter.validateSimulation();
@@ -476,8 +518,8 @@ public class ScenarioSimulationEventHandler implements AppendColumnEventHandler,
                     .append(" failure")
                     .toString();
             commonNotifyError(status, operation);
-        } else if (Objects.equals(CommandResultBuilder.SUCCESS, status) && (command instanceof AbstractScenarioGridCommand)) {
-            scenarioCommandRegistryManager.register(context, (AbstractScenarioGridCommand) command);
+        } else if (Objects.equals(CommandResultBuilder.SUCCESS, status) && (command instanceof AbstractScenarioSimulationUndoableCommand)) {
+            scenarioCommandRegistryManager.register(context, (AbstractScenarioSimulationUndoableCommand) command);
             if (focusGridAfterExecution && gridWidget.isPresent()) {
                 context.getScenarioGridPanelByGridWidget(gridWidget.get()).setFocus(true);
             }
@@ -521,6 +563,7 @@ public class ScenarioSimulationEventHandler implements AppendColumnEventHandler,
         handlerRegistrationList.add(eventBus.addHandler(SetPropertyHeaderEvent.TYPE, this));
         handlerRegistrationList.add(eventBus.addHandler(UndoEvent.TYPE, this));
         handlerRegistrationList.add(eventBus.addHandler(UnsupportedDMNEvent.TYPE, this));
+        handlerRegistrationList.add(eventBus.addHandler(UpdateSettingsDataEvent.TYPE, this));
         handlerRegistrationList.add(eventBus.addHandler(ValidateSimulationEvent.TYPE, this));
     }
 }
\ No newline at end of file
